@@ -3,12 +3,7 @@
 
 from trytond.pool import Pool
 
-from . import ir
-from . import marketing_automation
-from . import web
-from . import party
-from . import sale
-from . import routes
+from . import ir, marketing_automation, party, routes, sale, web
 
 __all__ = ['register', 'routes']
 
@@ -16,16 +11,15 @@ __all__ = ['register', 'routes']
 def register():
     Pool.register(
         ir.Cron,
+        ir.Email,
         marketing_automation.Scenario,
         marketing_automation.Activity,
         marketing_automation.Record,
         marketing_automation.RecordActivity,
+        party.Party,
+        party.PartyUnsubscribedScenario,
         web.ShortenedURL,
         module='marketing_automation', type_='model')
-    Pool.register(
-        party.Party,
-        module='marketing_automation', type_='model',
-        depends=['party'])
     Pool.register(
         sale.Sale,
         module='marketing_automation', type_='model',
